@@ -1,5 +1,5 @@
 test_that("simple pipe", {
-  pr <- newPowerRelationFromString('ab > a > b')
+  pr <- as.PowerRelation('ab > a > b')
 
   expect_equal(testRelation(pr, 'a'), list(pr, 'a'))
   expect_equal(pr %:% 'a', testRelation(pr, 'a'))
